@@ -1531,7 +1531,9 @@ check_gnutls_has_rehandshaking_bug (void)
           !strcmp (version, "3.2.19") ||
           !strcmp (version, "3.3.8") ||
           !strcmp (version, "3.3.9") ||
-          !strcmp (version, "3.3.10"));
+          !strcmp (version, "3.3.10") ||
+          !strcmp (version, "3.6.1") ||
+          !strcmp (version, "3.6.2"));
 }
 
 static void
@@ -1540,7 +1542,7 @@ test_simultaneous_async_rehandshake (TestConnection *test,
 {
   if (check_gnutls_has_rehandshaking_bug ())
     {
-      g_test_skip ("test would fail due to gnutls bug 108690");
+      g_test_skip ("test would fail due to https://bugzilla.gnome.org/show_bug.cgi?id=794286#c13");
       return;
     }
 
@@ -1640,7 +1642,7 @@ test_simultaneous_sync_rehandshake (TestConnection *test,
 {
   if (check_gnutls_has_rehandshaking_bug ())
     {
-      g_test_skip ("test would fail due to gnutls bug 108690");
+      g_test_skip ("test would fail due to https://bugzilla.gnome.org/show_bug.cgi?id=794286#c13");
       return;
     }
 
